@@ -563,6 +563,10 @@ namespace CEC
         return "2.0.2";
       case CEC_CLIENT_VERSION_2_0_3:
         return "2.0.3";
+      case CEC_CLIENT_VERSION_2_0_4:
+        return "2.0.4";
+      case CEC_CLIENT_VERSION_2_0_5:
+        return "2.0.5";
       default:
         return "Unknown";
       }
@@ -614,6 +618,10 @@ namespace CEC
         return "2.0.2";
       case CEC_SERVER_VERSION_2_0_3:
         return "2.0.3";
+      case CEC_SERVER_VERSION_2_0_4:
+        return "2.0.4";
+      case CEC_SERVER_VERSION_2_0_5:
+        return "2.0.5";
       default:
         return "Unknown";
       }
